﻿using RimWorld;
using System.Collections.Generic;
using Unity.Jobs;
using UnityEngine;
using Verse;
using Verse.AI;

namespace FoodPoisoningCures
{
    public class IngestionOutcomeDoer_RemoveHediff : IngestionOutcomeDoer
    {
        public HediffDef hediffDef;
        public override void DoIngestionOutcomeSpecial(Pawn pawn, Thing ingested)
        {
            var hediff = pawn.health.hediffSet.GetFirstHediffOfDef(hediffDef);
            if (hediff != null)
            {
                pawn.health.RemoveHediff(hediff);
            }
        }
    }

    public class Hediff_VomitUntilFoodBarIsEmpty : Hediff
    {
        public override bool ShouldRemove => pawn.needs.food.CurLevelPercentage <= 0.01f;
        public override void Tick()
        {
            base.Tick();
            if (this.pawn.CurJobDef != JobDefOf.Vomit)
            {
                pawn.jobs.StartJob(JobMaker.MakeJob(JobDefOf.Vomit), JobCondition.InterruptForced, null, resumeCurJobAfterwards: true);
            }
            if (Find.TickManager.TicksGame % 150 == 0)
            {
                pawn.needs.food.CurLevel -= pawn.needs.food.MaxLevel * 0.04f;
            }
        }

        public override void PostRemoved()
        {
            base.PostRemoved();
            var foodPoison = pawn.health.hediffSet.GetFirstHediffOfDef(HediffDefOf.FoodPoisoning);
            if (foodPoison != null && foodPoison.Severity > 0.1f)
            {
                foodPoison.Severity = 0.1f;
            }
        }
    }
}
